@@ -278,20 +278,23 @@ class Command:
                     raise SubCmdError
             else:
                 for name, cmd in self.subs.items():
-                    if cmd.shortcut:
-                        cmd.parent = self
-                        try:
-                            return cmd(args)
-                        except SubCmdError:
-                            return
-                        except ValidationError:
-                            continue
-                    else:
-                        cmd = cmd.subs and cmd.subs.get(self.args[0])
-                        if cmd:
+                    try:
+                        if cmd.shortcut:
                             cmd.parent = self
-                            self._args = self._args[1:]
-                            return cmd(' '.join(self.args))
+                            try:
+                                return cmd(args)
+                            except SubCmdError:
+                                return
+                            except ValidationError:
+                                continue
+                        else:
+                            cmd = cmd.subs and cmd.subs.get(self.args[0])
+                            if cmd:
+                                cmd.parent = self
+                                self._args = self._args[1:]
+                                return cmd(' '.join(self.args))
+                    except Exception as x:
+                        print(f' ! {name} - {cmd} ! {x} ! ')
 
             if self.parent:
                 raise ValidationError
