@@ -1,6 +1,6 @@
 from sys import exit
 
-from pybrary.commandline import parse_args
+from pybrary.command import parse_args
 from pybrary import commands
 
 
